@@ -46,7 +46,7 @@ with open(os.path.join(here, "__version__.py")) as f:
 
 about =f'''nomhsms. Version {version["__version__"]}
 
-Graphical user interface for nomhsms package (https://github.com/nomhsms/nomhsms)
+Graphical user interface for nomhsms package: https://github.com/nomhsms/nomhsms
 
 Tutorial: https://nomhsms.readthedocs.io/en/latest/gui_tutorial.html
 
@@ -645,7 +645,7 @@ class App(QtWidgets.QMainWindow, Ui_MainWindow):
     def add_bufer_(self):
 
         try:
-            self.specs_list.append(self.spec)
+            self.specs_list.append(copy.deepcopy(self.spec))
             self.listWidget.insertItem(self.listWidget.count(), self.specs_list[-1].metadata['name'])
             self.listWidget.item(self.listWidget.count()-1).setCheckState(0)
             self.listWidget.setCurrentRow(self.listWidget.count()-1)
@@ -738,29 +738,34 @@ class App(QtWidgets.QMainWindow, Ui_MainWindow):
                 obj[i] = spec.calc_mass()
                 obj[i].table = obj[i].table.dropna()
 
-            self.spec = obj[0]
+            temp_spec = obj[0]
             if op == 'and':
                 for i in range(1, len(obj)):
-                    self.spec = self.spec & obj[i]
+                    temp_spec = temp_spec & obj[i]
                 self.addText('and')
             elif op == 'add':
                 for i in range(1, len(obj)):
-                    self.spec = self.spec + obj[i]
+                    temp_spec = temp_spec + obj[i]
                 self.addText('add')
             elif op == 'sub':
                 for i in range(1, len(obj)):
-                    self.spec = self.spec - obj[i]
+                    temp_spec = temp_spec - obj[i]
                 self.addText('sub')
             elif op == 'xor':
                 for i in range(1, len(obj)):
-                    self.spec = self.spec ^ obj[i]
+                    temp_spec = temp_spec ^ obj[i]
                 self.addText('xor')
             elif op == 'int_sub':
                 for i in range(1, len(obj)):
-                    self.spec = self.spec.intens_sub(obj[i])
+                    temp_spec = temp_spec.intens_sub(obj[i])
                 self.addText('int_sub')
 
-            self.add_bufer_()
+            self.specs_list.append(copy.deepcopy(temp_spec))
+            self.listWidget.insertItem(self.listWidget.count(), self.specs_list[-1].metadata['name'])
+            self.listWidget.item(self.listWidget.count()-1).setCheckState(0)
+            self.listWidget.setCurrentRow(self.listWidget.count()-1)
+            self.specs_list[-1].metadata['color'] = def_colors[len(self.specs_list)%10]
+            self.specs_list[-1].metadata['alpha'] = 0.2
 
         except Exception:
             self.addText(traceback.format_exc())
@@ -769,8 +774,6 @@ class App(QtWidgets.QMainWindow, Ui_MainWindow):
         
         try:
             self.form_temp_list()
-            if len(self.temp_list) != 3 or len(self.temp_list) != 2:
-                raise Exception(f"This can be done for two or three spectra, not for {len(self.temp_list)}")
 
             obj = copy.deepcopy(self.temp_list)
             sets = []
@@ -787,6 +790,9 @@ class App(QtWidgets.QMainWindow, Ui_MainWindow):
 
             elif len(self.temp_list) == 3:
                 venn3([set(sets[0]), set(sets[1]), set(sets[2])], set_labels=labels, ax=ax)
+
+            else:
+                raise Exception(f"This can be done for two or three spectra, not for {len(self.temp_list)}")
             
             self.addText('venn')
 
@@ -1033,11 +1039,8 @@ class App(QtWidgets.QMainWindow, Ui_MainWindow):
             if spec_num < 1:
                 raise Exception("no spectrum for plot. Try to add by click")
 
-            if len(self.plot_color) == spec_num:
-                col = self.plot_color
-            else:
-                col = default_colors[:spec_num]
-
+            col = self.plot_color
+            
             dt = []
             for i, spec in enumerate(obj):
                 val = spec.get_dbe_vs_o(ax=ax, olim=lim, c=col[i])                   
